pub enum ScrollDeltaUnit {
Line,
Pixel,
}Expand description
Indicates the unit used by the platform to describe a scroll delta.
Variants
Line
Delta is expressed as a logical number of lines or wheel steps.
Pixel
Delta is expressed in pixels.