current_frame_time

Function current_frame_time 

pub fn current_frame_time() -> Option<Instant>
Returns the timestamp of the current frame, if available.

The value is set by the renderer at frame begin.