Callback

Struct Callback 

pub struct Callback { /* private fields */ }
Stable, comparable callback handle for Fn().

Callback is a stable handle to the latest callback closure created at the same build call site.

Callback identity does not change when the captured closure changes during recomposition. As a result, callback updates do not force prop mismatches or replay invalidation. Event handlers always invoke the latest closure stored behind the handle.

Create callbacks only during a Tessera component build.

Implementations

Source

impl Callback

pub fn new<F>(handler: F) -> Self
where F: Fn() + Send + Sync + 'static,

Create a callback handle from a closure.

This must be called during a component build.

pub const fn noop() -> Self

Create an empty callback.

pub fn call(&self)

Invoke the callback.