ImeRequest

Struct ImeRequest 

pub struct ImeRequest {
    pub size: PxSize,
    pub local_position: PxPosition,
    pub selection_range: Option<Range<usize>>,
    pub composition_range: Option<Range<usize>>,
    /* private fields */
}
A request to the windowing system to open an Input Method Editor (IME). This is typically used for text input components.

Fields

size: PxSize

The size of the area where the IME is requested.

local_position: PxPosition

The position of the IME anchor relative to the requesting node.

selection_range: Option<Range<usize>>

The current ordered selection range in the backing text buffer.

composition_range: Option<Range<usize>>

The current ordered composition range in the backing text buffer.

Implementations

Source

impl ImeRequest

pub fn new(size: PxSize) -> Self

Creates a new IME request with the target input area size.

The absolute position is injected during the compute pass.

pub fn with_local_position(self, local_position: PxPosition) -> Self

Sets the position of the IME anchor relative to the requesting node.

pub fn with_selection_range(self, selection_range: Option<Range<usize>>) -> Self

Sets the current ordered text selection range.

pub fn with_composition_range( self, composition_range: Option<Range<usize>>, ) -> Self

Sets the current ordered text composition range.