pub struct ParentConstraint<'a>(/* private fields */);Expand description
The constraint inherited from a parent node during measurement.
Implementations
Sourceimpl<'a> ParentConstraint<'a>
impl<'a> ParentConstraint<'a>
Sourcepub const fn width(self) -> AxisConstraint
pub const fn width(self) -> AxisConstraint
Returns the inherited width constraint.
Sourcepub const fn height(self) -> AxisConstraint
pub const fn height(self) -> AxisConstraint
Returns the inherited height constraint.
Sourcepub const fn as_ref(self) -> &'a Constraint
pub const fn as_ref(self) -> &'a Constraint
Returns a reference to the underlying constraint.
Sourcepub const fn without_min(self) -> Constraint
pub const fn without_min(self) -> Constraint
Returns the inherited constraint with both lower bounds cleared.