pub struct RenderFragment { /* private fields */ }Expand description
A per-component render fragment.
Implementations
Sourceimpl RenderFragment
impl RenderFragment
Sourcepub fn ops(&self) -> &[RenderFragmentOp]
pub fn ops(&self) -> &[RenderFragmentOp]
Returns fragment ops in insertion order.
Sourcepub fn resources(&self) -> &[RenderResource]
pub fn resources(&self) -> &[RenderResource]
Returns local resources declared by this fragment.
Sourcepub fn add_local_texture(&mut self, desc: RenderTextureDesc) -> RenderResourceId
pub fn add_local_texture(&mut self, desc: RenderTextureDesc) -> RenderResourceId
Adds a local texture resource to the fragment.
Sourcepub fn push_draw_command<C: DrawCommand + 'static>(&mut self, command: C) -> u32
pub fn push_draw_command<C: DrawCommand + 'static>(&mut self, command: C) -> u32
Adds a draw command with default scene resource bindings.
Sourcepub fn push_compute_command<C: ComputeCommand + 'static>(
&mut self,
command: C,
) -> u32
pub fn push_compute_command<C: ComputeCommand + 'static>( &mut self, command: C, ) -> u32
Adds a compute command with default scene resource bindings.
Sourcepub fn push_composite_command<C: CompositeCommand + 'static>(
&mut self,
command: C,
) -> u32
pub fn push_composite_command<C: CompositeCommand + 'static>( &mut self, command: C, ) -> u32
Adds a composite command with default scene resource bindings.
Sourcepub fn push_op(&mut self, op: RenderFragmentOp) -> u32
pub fn push_op(&mut self, op: RenderFragmentOp) -> u32
Adds a render op to the fragment.