pub struct RenderSlot { /* private fields */ }Expand description
Stable, comparable render slot handle.
RenderSlot is a stable handle to deferred UI content.
Like Callback, the handle stays stable across recomposition. Unlike
callbacks, updating a render slot’s closure invalidates component instances
that rendered the slot, so slot content changes can trigger replayed
components to rebuild with the latest UI.
Create render slots only during a Tessera component build.
Implementations