pub struct Callback { /* private fields */ }Expand description
Stable, comparable callback handle for Fn().
Callback is a stable handle to the latest callback closure created at the
same build call site.
Callback identity does not change when the captured closure changes during recomposition. As a result, callback updates do not force prop mismatches or replay invalidation. Event handlers always invoke the latest closure stored behind the handle.
Create callbacks only during a Tessera component build.
Implementations