pub struct ParentConstraint<'a>(/* private fields */);Expand description
The constraint inherited from a parent node during measurement.
This wrapper exists to make APIs that combine constraints less error-prone. A parent constraint is provided by the layout engine and is not meant to be synthesized by user code.
Implementations
Sourceimpl<'a> ParentConstraint<'a>
impl<'a> ParentConstraint<'a>
Sourcepub const fn width(self) -> DimensionValue
pub const fn width(self) -> DimensionValue
Returns the inherited width constraint.
Sourcepub const fn height(self) -> DimensionValue
pub const fn height(self) -> DimensionValue
Returns the inherited height constraint.
Sourcepub const fn as_ref(self) -> &'a Constraint
pub const fn as_ref(self) -> &'a Constraint
Returns a reference to the underlying Constraint.